# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: v1.7.3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into sdk package
from .models.apps_v1beta1_deployment import AppsV1beta1Deployment
from .models.apps_v1beta1_deployment_condition import AppsV1beta1DeploymentCondition
from .models.apps_v1beta1_deployment_list import AppsV1beta1DeploymentList
from .models.apps_v1beta1_deployment_rollback import AppsV1beta1DeploymentRollback
from .models.apps_v1beta1_deployment_spec import AppsV1beta1DeploymentSpec
from .models.apps_v1beta1_deployment_status import AppsV1beta1DeploymentStatus
from .models.apps_v1beta1_deployment_strategy import AppsV1beta1DeploymentStrategy
from .models.apps_v1beta1_rollback_config import AppsV1beta1RollbackConfig
from .models.apps_v1beta1_rolling_update_deployment import AppsV1beta1RollingUpdateDeployment
from .models.apps_v1beta1_scale import AppsV1beta1Scale
from .models.apps_v1beta1_scale_spec import AppsV1beta1ScaleSpec
from .models.apps_v1beta1_scale_status import AppsV1beta1ScaleStatus
from .models.extensions_v1beta1_deployment import ExtensionsV1beta1Deployment
from .models.extensions_v1beta1_deployment_condition import ExtensionsV1beta1DeploymentCondition
from .models.extensions_v1beta1_deployment_list import ExtensionsV1beta1DeploymentList
from .models.extensions_v1beta1_deployment_rollback import ExtensionsV1beta1DeploymentRollback
from .models.extensions_v1beta1_deployment_spec import ExtensionsV1beta1DeploymentSpec
from .models.extensions_v1beta1_deployment_status import ExtensionsV1beta1DeploymentStatus
from .models.extensions_v1beta1_deployment_strategy import ExtensionsV1beta1DeploymentStrategy
from .models.extensions_v1beta1_rollback_config import ExtensionsV1beta1RollbackConfig
from .models.extensions_v1beta1_rolling_update_deployment import ExtensionsV1beta1RollingUpdateDeployment
from .models.extensions_v1beta1_scale import ExtensionsV1beta1Scale
from .models.extensions_v1beta1_scale_spec import ExtensionsV1beta1ScaleSpec
from .models.extensions_v1beta1_scale_status import ExtensionsV1beta1ScaleStatus
from .models.runtime_raw_extension import RuntimeRawExtension
from .models.v1_api_group import V1APIGroup
from .models.v1_api_group_list import V1APIGroupList
from .models.v1_api_resource import V1APIResource
from .models.v1_api_resource_list import V1APIResourceList
from .models.v1_api_versions import V1APIVersions
from .models.v1_aws_elastic_block_store_volume_source import V1AWSElasticBlockStoreVolumeSource
from .models.v1_affinity import V1Affinity
from .models.v1_attached_volume import V1AttachedVolume
from .models.v1_azure_disk_volume_source import V1AzureDiskVolumeSource
from .models.v1_azure_file_volume_source import V1AzureFileVolumeSource
from .models.v1_binding import V1Binding
from .models.v1_capabilities import V1Capabilities
from .models.v1_ceph_fs_volume_source import V1CephFSVolumeSource
from .models.v1_cinder_volume_source import V1CinderVolumeSource
from .models.v1_component_condition import V1ComponentCondition
from .models.v1_component_status import V1ComponentStatus
from .models.v1_component_status_list import V1ComponentStatusList
from .models.v1_config_map import V1ConfigMap
from .models.v1_config_map_env_source import V1ConfigMapEnvSource
from .models.v1_config_map_key_selector import V1ConfigMapKeySelector
from .models.v1_config_map_list import V1ConfigMapList
from .models.v1_config_map_projection import V1ConfigMapProjection
from .models.v1_config_map_volume_source import V1ConfigMapVolumeSource
from .models.v1_container import V1Container
from .models.v1_container_image import V1ContainerImage
from .models.v1_container_port import V1ContainerPort
from .models.v1_container_state import V1ContainerState
from .models.v1_container_state_running import V1ContainerStateRunning
from .models.v1_container_state_terminated import V1ContainerStateTerminated
from .models.v1_container_state_waiting import V1ContainerStateWaiting
from .models.v1_container_status import V1ContainerStatus
from .models.v1_cross_version_object_reference import V1CrossVersionObjectReference
from .models.v1_daemon_endpoint import V1DaemonEndpoint
from .models.v1_delete_options import V1DeleteOptions
from .models.v1_downward_api_projection import V1DownwardAPIProjection
from .models.v1_downward_api_volume_file import V1DownwardAPIVolumeFile
from .models.v1_downward_api_volume_source import V1DownwardAPIVolumeSource
from .models.v1_empty_dir_volume_source import V1EmptyDirVolumeSource
from .models.v1_endpoint_address import V1EndpointAddress
from .models.v1_endpoint_port import V1EndpointPort
from .models.v1_endpoint_subset import V1EndpointSubset
from .models.v1_endpoints import V1Endpoints
from .models.v1_endpoints_list import V1EndpointsList
from .models.v1_env_from_source import V1EnvFromSource
from .models.v1_env_var import V1EnvVar
from .models.v1_env_var_source import V1EnvVarSource
from .models.v1_event import V1Event
from .models.v1_event_list import V1EventList
from .models.v1_event_source import V1EventSource
from .models.v1_exec_action import V1ExecAction
from .models.v1_fc_volume_source import V1FCVolumeSource
from .models.v1_flex_volume_source import V1FlexVolumeSource
from .models.v1_flocker_volume_source import V1FlockerVolumeSource
from .models.v1_gce_persistent_disk_volume_source import V1GCEPersistentDiskVolumeSource
from .models.v1_git_repo_volume_source import V1GitRepoVolumeSource
from .models.v1_glusterfs_volume_source import V1GlusterfsVolumeSource
from .models.v1_group_version_for_discovery import V1GroupVersionForDiscovery
from .models.v1_http_get_action import V1HTTPGetAction
from .models.v1_http_header import V1HTTPHeader
from .models.v1_handler import V1Handler
from .models.v1_horizontal_pod_autoscaler import V1HorizontalPodAutoscaler
from .models.v1_horizontal_pod_autoscaler_list import V1HorizontalPodAutoscalerList
from .models.v1_horizontal_pod_autoscaler_spec import V1HorizontalPodAutoscalerSpec
from .models.v1_horizontal_pod_autoscaler_status import V1HorizontalPodAutoscalerStatus
from .models.v1_host_alias import V1HostAlias
from .models.v1_host_path_volume_source import V1HostPathVolumeSource
from .models.v1_iscsi_volume_source import V1ISCSIVolumeSource
from .models.v1_initializer import V1Initializer
from .models.v1_initializers import V1Initializers
from .models.v1_job import V1Job
from .models.v1_job_condition import V1JobCondition
from .models.v1_job_list import V1JobList
from .models.v1_job_spec import V1JobSpec
from .models.v1_job_status import V1JobStatus
from .models.v1_key_to_path import V1KeyToPath
from .models.v1_label_selector import V1LabelSelector
from .models.v1_label_selector_requirement import V1LabelSelectorRequirement
from .models.v1_lifecycle import V1Lifecycle
from .models.v1_limit_range import V1LimitRange
from .models.v1_limit_range_item import V1LimitRangeItem
from .models.v1_limit_range_list import V1LimitRangeList
from .models.v1_limit_range_spec import V1LimitRangeSpec
from .models.v1_list_meta import V1ListMeta
from .models.v1_load_balancer_ingress import V1LoadBalancerIngress
from .models.v1_load_balancer_status import V1LoadBalancerStatus
from .models.v1_local_object_reference import V1LocalObjectReference
from .models.v1_local_subject_access_review import V1LocalSubjectAccessReview
from .models.v1_local_volume_source import V1LocalVolumeSource
from .models.v1_nfs_volume_source import V1NFSVolumeSource
from .models.v1_namespace import V1Namespace
from .models.v1_namespace_list import V1NamespaceList
from .models.v1_namespace_spec import V1NamespaceSpec
from .models.v1_namespace_status import V1NamespaceStatus
from .models.v1_network_policy import V1NetworkPolicy
from .models.v1_network_policy_ingress_rule import V1NetworkPolicyIngressRule
from .models.v1_network_policy_list import V1NetworkPolicyList
from .models.v1_network_policy_peer import V1NetworkPolicyPeer
from .models.v1_network_policy_port import V1NetworkPolicyPort
from .models.v1_network_policy_spec import V1NetworkPolicySpec
from .models.v1_node import V1Node
from .models.v1_node_address import V1NodeAddress
from .models.v1_node_affinity import V1NodeAffinity
from .models.v1_node_condition import V1NodeCondition
from .models.v1_node_daemon_endpoints import V1NodeDaemonEndpoints
from .models.v1_node_list import V1NodeList
from .models.v1_node_selector import V1NodeSelector
from .models.v1_node_selector_requirement import V1NodeSelectorRequirement
from .models.v1_node_selector_term import V1NodeSelectorTerm
from .models.v1_node_spec import V1NodeSpec
from .models.v1_node_status import V1NodeStatus
from .models.v1_node_system_info import V1NodeSystemInfo
from .models.v1_non_resource_attributes import V1NonResourceAttributes
from .models.v1_object_field_selector import V1ObjectFieldSelector
from .models.v1_object_meta import V1ObjectMeta
from .models.v1_object_reference import V1ObjectReference
from .models.v1_owner_reference import V1OwnerReference
from .models.v1_persistent_volume import V1PersistentVolume
from .models.v1_persistent_volume_claim import V1PersistentVolumeClaim
from .models.v1_persistent_volume_claim_list import V1PersistentVolumeClaimList
from .models.v1_persistent_volume_claim_spec import V1PersistentVolumeClaimSpec
from .models.v1_persistent_volume_claim_status import V1PersistentVolumeClaimStatus
from .models.v1_persistent_volume_claim_volume_source import V1PersistentVolumeClaimVolumeSource
from .models.v1_persistent_volume_list import V1PersistentVolumeList
from .models.v1_persistent_volume_spec import V1PersistentVolumeSpec
from .models.v1_persistent_volume_status import V1PersistentVolumeStatus
from .models.v1_photon_persistent_disk_volume_source import V1PhotonPersistentDiskVolumeSource
from .models.v1_pod import V1Pod
from .models.v1_pod_affinity import V1PodAffinity
from .models.v1_pod_affinity_term import V1PodAffinityTerm
from .models.v1_pod_anti_affinity import V1PodAntiAffinity
from .models.v1_pod_condition import V1PodCondition
from .models.v1_pod_list import V1PodList
from .models.v1_pod_security_context import V1PodSecurityContext
from .models.v1_pod_spec import V1PodSpec
from .models.v1_pod_status import V1PodStatus
from .models.v1_pod_template import V1PodTemplate
from .models.v1_pod_template_list import V1PodTemplateList
from .models.v1_pod_template_spec import V1PodTemplateSpec
from .models.v1_portworx_volume_source import V1PortworxVolumeSource
from .models.v1_preconditions import V1Preconditions
from .models.v1_preferred_scheduling_term import V1PreferredSchedulingTerm
from .models.v1_probe import V1Probe
from .models.v1_projected_volume_source import V1ProjectedVolumeSource
from .models.v1_quobyte_volume_source import V1QuobyteVolumeSource
from .models.v1_rbd_volume_source import V1RBDVolumeSource
from .models.v1_replication_controller import V1ReplicationController
from .models.v1_replication_controller_condition import V1ReplicationControllerCondition
from .models.v1_replication_controller_list import V1ReplicationControllerList
from .models.v1_replication_controller_spec import V1ReplicationControllerSpec
from .models.v1_replication_controller_status import V1ReplicationControllerStatus
from .models.v1_resource_attributes import V1ResourceAttributes
from .models.v1_resource_field_selector import V1ResourceFieldSelector
from .models.v1_resource_quota import V1ResourceQuota
from .models.v1_resource_quota_list import V1ResourceQuotaList
from .models.v1_resource_quota_spec import V1ResourceQuotaSpec
from .models.v1_resource_quota_status import V1ResourceQuotaStatus
from .models.v1_resource_requirements import V1ResourceRequirements
from .models.v1_se_linux_options import V1SELinuxOptions
from .models.v1_scale import V1Scale
from .models.v1_scale_io_volume_source import V1ScaleIOVolumeSource
from .models.v1_scale_spec import V1ScaleSpec
from .models.v1_scale_status import V1ScaleStatus
from .models.v1_secret import V1Secret
from .models.v1_secret_env_source import V1SecretEnvSource
from .models.v1_secret_key_selector import V1SecretKeySelector
from .models.v1_secret_list import V1SecretList
from .models.v1_secret_projection import V1SecretProjection
from .models.v1_secret_volume_source import V1SecretVolumeSource
from .models.v1_security_context import V1SecurityContext
from .models.v1_self_subject_access_review import V1SelfSubjectAccessReview
from .models.v1_self_subject_access_review_spec import V1SelfSubjectAccessReviewSpec
from .models.v1_server_address_by_client_cidr import V1ServerAddressByClientCIDR
from .models.v1_service import V1Service
from .models.v1_service_account import V1ServiceAccount
from .models.v1_service_account_list import V1ServiceAccountList
from .models.v1_service_list import V1ServiceList
from .models.v1_service_port import V1ServicePort
from .models.v1_service_spec import V1ServiceSpec
from .models.v1_service_status import V1ServiceStatus
from .models.v1_status import V1Status
from .models.v1_status_cause import V1StatusCause
from .models.v1_status_details import V1StatusDetails
from .models.v1_storage_class import V1StorageClass
from .models.v1_storage_class_list import V1StorageClassList
from .models.v1_storage_os_persistent_volume_source import V1StorageOSPersistentVolumeSource
from .models.v1_storage_os_volume_source import V1StorageOSVolumeSource
from .models.v1_subject_access_review import V1SubjectAccessReview
from .models.v1_subject_access_review_spec import V1SubjectAccessReviewSpec
from .models.v1_subject_access_review_status import V1SubjectAccessReviewStatus
from .models.v1_tcp_socket_action import V1TCPSocketAction
from .models.v1_taint import V1Taint
from .models.v1_token_review import V1TokenReview
from .models.v1_token_review_spec import V1TokenReviewSpec
from .models.v1_token_review_status import V1TokenReviewStatus
from .models.v1_toleration import V1Toleration
from .models.v1_user_info import V1UserInfo
from .models.v1_volume import V1Volume
from .models.v1_volume_mount import V1VolumeMount
from .models.v1_volume_projection import V1VolumeProjection
from .models.v1_vsphere_virtual_disk_volume_source import V1VsphereVirtualDiskVolumeSource
from .models.v1_watch_event import V1WatchEvent
from .models.v1_weighted_pod_affinity_term import V1WeightedPodAffinityTerm
from .models.v1alpha1_admission_hook_client_config import V1alpha1AdmissionHookClientConfig
from .models.v1alpha1_cluster_role import V1alpha1ClusterRole
from .models.v1alpha1_cluster_role_binding import V1alpha1ClusterRoleBinding
from .models.v1alpha1_cluster_role_binding_list import V1alpha1ClusterRoleBindingList
from .models.v1alpha1_cluster_role_list import V1alpha1ClusterRoleList
from .models.v1alpha1_external_admission_hook import V1alpha1ExternalAdmissionHook
from .models.v1alpha1_external_admission_hook_configuration import V1alpha1ExternalAdmissionHookConfiguration
from .models.v1alpha1_external_admission_hook_configuration_list import V1alpha1ExternalAdmissionHookConfigurationList
from .models.v1alpha1_initializer import V1alpha1Initializer
from .models.v1alpha1_initializer_configuration import V1alpha1InitializerConfiguration
from .models.v1alpha1_initializer_configuration_list import V1alpha1InitializerConfigurationList
from .models.v1alpha1_pod_preset import V1alpha1PodPreset
from .models.v1alpha1_pod_preset_list import V1alpha1PodPresetList
from .models.v1alpha1_pod_preset_spec import V1alpha1PodPresetSpec
from .models.v1alpha1_policy_rule import V1alpha1PolicyRule
from .models.v1alpha1_role import V1alpha1Role
from .models.v1alpha1_role_binding import V1alpha1RoleBinding
from .models.v1alpha1_role_binding_list import V1alpha1RoleBindingList
from .models.v1alpha1_role_list import V1alpha1RoleList
from .models.v1alpha1_role_ref import V1alpha1RoleRef
from .models.v1alpha1_rule import V1alpha1Rule
from .models.v1alpha1_rule_with_operations import V1alpha1RuleWithOperations
from .models.v1alpha1_service_reference import V1alpha1ServiceReference
from .models.v1alpha1_subject import V1alpha1Subject
from .models.v1beta1_api_service import V1beta1APIService
from .models.v1beta1_api_service_condition import V1beta1APIServiceCondition
from .models.v1beta1_api_service_list import V1beta1APIServiceList
from .models.v1beta1_api_service_spec import V1beta1APIServiceSpec
from .models.v1beta1_api_service_status import V1beta1APIServiceStatus
from .models.v1beta1_api_version import V1beta1APIVersion
from .models.v1beta1_certificate_signing_request import V1beta1CertificateSigningRequest
from .models.v1beta1_certificate_signing_request_condition import V1beta1CertificateSigningRequestCondition
from .models.v1beta1_certificate_signing_request_list import V1beta1CertificateSigningRequestList
from .models.v1beta1_certificate_signing_request_spec import V1beta1CertificateSigningRequestSpec
from .models.v1beta1_certificate_signing_request_status import V1beta1CertificateSigningRequestStatus
from .models.v1beta1_cluster_role import V1beta1ClusterRole
from .models.v1beta1_cluster_role_binding import V1beta1ClusterRoleBinding
from .models.v1beta1_cluster_role_binding_list import V1beta1ClusterRoleBindingList
from .models.v1beta1_cluster_role_list import V1beta1ClusterRoleList
from .models.v1beta1_controller_revision import V1beta1ControllerRevision
from .models.v1beta1_controller_revision_list import V1beta1ControllerRevisionList
from .models.v1beta1_daemon_set import V1beta1DaemonSet
from .models.v1beta1_daemon_set_list import V1beta1DaemonSetList
from .models.v1beta1_daemon_set_spec import V1beta1DaemonSetSpec
from .models.v1beta1_daemon_set_status import V1beta1DaemonSetStatus
from .models.v1beta1_daemon_set_update_strategy import V1beta1DaemonSetUpdateStrategy
from .models.v1beta1_eviction import V1beta1Eviction
from .models.v1beta1_fs_group_strategy_options import V1beta1FSGroupStrategyOptions
from .models.v1beta1_http_ingress_path import V1beta1HTTPIngressPath
from .models.v1beta1_http_ingress_rule_value import V1beta1HTTPIngressRuleValue
from .models.v1beta1_host_port_range import V1beta1HostPortRange
from .models.v1beta1_id_range import V1beta1IDRange
from .models.v1beta1_ingress import V1beta1Ingress
from .models.v1beta1_ingress_backend import V1beta1IngressBackend
from .models.v1beta1_ingress_list import V1beta1IngressList
from .models.v1beta1_ingress_rule import V1beta1IngressRule
from .models.v1beta1_ingress_spec import V1beta1IngressSpec
from .models.v1beta1_ingress_status import V1beta1IngressStatus
from .models.v1beta1_ingress_tls import V1beta1IngressTLS
from .models.v1beta1_local_subject_access_review import V1beta1LocalSubjectAccessReview
from .models.v1beta1_network_policy import V1beta1NetworkPolicy
from .models.v1beta1_network_policy_ingress_rule import V1beta1NetworkPolicyIngressRule
from .models.v1beta1_network_policy_list import V1beta1NetworkPolicyList
from .models.v1beta1_network_policy_peer import V1beta1NetworkPolicyPeer
from .models.v1beta1_network_policy_port import V1beta1NetworkPolicyPort
from .models.v1beta1_network_policy_spec import V1beta1NetworkPolicySpec
from .models.v1beta1_non_resource_attributes import V1beta1NonResourceAttributes
from .models.v1beta1_pod_disruption_budget import V1beta1PodDisruptionBudget
from .models.v1beta1_pod_disruption_budget_list import V1beta1PodDisruptionBudgetList
from .models.v1beta1_pod_disruption_budget_spec import V1beta1PodDisruptionBudgetSpec
from .models.v1beta1_pod_disruption_budget_status import V1beta1PodDisruptionBudgetStatus
from .models.v1beta1_pod_security_policy import V1beta1PodSecurityPolicy
from .models.v1beta1_pod_security_policy_list import V1beta1PodSecurityPolicyList
from .models.v1beta1_pod_security_policy_spec import V1beta1PodSecurityPolicySpec
from .models.v1beta1_policy_rule import V1beta1PolicyRule
from .models.v1beta1_replica_set import V1beta1ReplicaSet
from .models.v1beta1_replica_set_condition import V1beta1ReplicaSetCondition
from .models.v1beta1_replica_set_list import V1beta1ReplicaSetList
from .models.v1beta1_replica_set_spec import V1beta1ReplicaSetSpec
from .models.v1beta1_replica_set_status import V1beta1ReplicaSetStatus
from .models.v1beta1_resource_attributes import V1beta1ResourceAttributes
from .models.v1beta1_role import V1beta1Role
from .models.v1beta1_role_binding import V1beta1RoleBinding
from .models.v1beta1_role_binding_list import V1beta1RoleBindingList
from .models.v1beta1_role_list import V1beta1RoleList
from .models.v1beta1_role_ref import V1beta1RoleRef
from .models.v1beta1_rolling_update_daemon_set import V1beta1RollingUpdateDaemonSet
from .models.v1beta1_rolling_update_stateful_set_strategy import V1beta1RollingUpdateStatefulSetStrategy
from .models.v1beta1_run_as_user_strategy_options import V1beta1RunAsUserStrategyOptions
from .models.v1beta1_se_linux_strategy_options import V1beta1SELinuxStrategyOptions
from .models.v1beta1_self_subject_access_review import V1beta1SelfSubjectAccessReview
from .models.v1beta1_self_subject_access_review_spec import V1beta1SelfSubjectAccessReviewSpec
from .models.v1beta1_service_reference import V1beta1ServiceReference
from .models.v1beta1_stateful_set import V1beta1StatefulSet
from .models.v1beta1_stateful_set_list import V1beta1StatefulSetList
from .models.v1beta1_stateful_set_spec import V1beta1StatefulSetSpec
from .models.v1beta1_stateful_set_status import V1beta1StatefulSetStatus
from .models.v1beta1_stateful_set_update_strategy import V1beta1StatefulSetUpdateStrategy
from .models.v1beta1_storage_class import V1beta1StorageClass
from .models.v1beta1_storage_class_list import V1beta1StorageClassList
from .models.v1beta1_subject import V1beta1Subject
from .models.v1beta1_subject_access_review import V1beta1SubjectAccessReview
from .models.v1beta1_subject_access_review_spec import V1beta1SubjectAccessReviewSpec
from .models.v1beta1_subject_access_review_status import V1beta1SubjectAccessReviewStatus
from .models.v1beta1_supplemental_groups_strategy_options import V1beta1SupplementalGroupsStrategyOptions
from .models.v1beta1_third_party_resource import V1beta1ThirdPartyResource
from .models.v1beta1_third_party_resource_list import V1beta1ThirdPartyResourceList
from .models.v1beta1_token_review import V1beta1TokenReview
from .models.v1beta1_token_review_spec import V1beta1TokenReviewSpec
from .models.v1beta1_token_review_status import V1beta1TokenReviewStatus
from .models.v1beta1_user_info import V1beta1UserInfo
from .models.v2alpha1_cron_job import V2alpha1CronJob
from .models.v2alpha1_cron_job_list import V2alpha1CronJobList
from .models.v2alpha1_cron_job_spec import V2alpha1CronJobSpec
from .models.v2alpha1_cron_job_status import V2alpha1CronJobStatus
from .models.v2alpha1_cross_version_object_reference import V2alpha1CrossVersionObjectReference
from .models.v2alpha1_horizontal_pod_autoscaler import V2alpha1HorizontalPodAutoscaler
from .models.v2alpha1_horizontal_pod_autoscaler_condition import V2alpha1HorizontalPodAutoscalerCondition
from .models.v2alpha1_horizontal_pod_autoscaler_list import V2alpha1HorizontalPodAutoscalerList
from .models.v2alpha1_horizontal_pod_autoscaler_spec import V2alpha1HorizontalPodAutoscalerSpec
from .models.v2alpha1_horizontal_pod_autoscaler_status import V2alpha1HorizontalPodAutoscalerStatus
from .models.v2alpha1_job_template_spec import V2alpha1JobTemplateSpec
from .models.v2alpha1_metric_spec import V2alpha1MetricSpec
from .models.v2alpha1_metric_status import V2alpha1MetricStatus
from .models.v2alpha1_object_metric_source import V2alpha1ObjectMetricSource
from .models.v2alpha1_object_metric_status import V2alpha1ObjectMetricStatus
from .models.v2alpha1_pods_metric_source import V2alpha1PodsMetricSource
from .models.v2alpha1_pods_metric_status import V2alpha1PodsMetricStatus
from .models.v2alpha1_resource_metric_source import V2alpha1ResourceMetricSource
from .models.v2alpha1_resource_metric_status import V2alpha1ResourceMetricStatus
from .models.version_info import VersionInfo

# import apis into sdk package
from .apis.admissionregistration_api import AdmissionregistrationApi
from .apis.admissionregistration_v1alpha1_api import AdmissionregistrationV1alpha1Api
from .apis.apiregistration_api import ApiregistrationApi
from .apis.apiregistration_v1beta1_api import ApiregistrationV1beta1Api
from .apis.apis_api import ApisApi
from .apis.apps_api import AppsApi
from .apis.apps_v1beta1_api import AppsV1beta1Api
from .apis.authentication_api import AuthenticationApi
from .apis.authentication_v1_api import AuthenticationV1Api
from .apis.authentication_v1beta1_api import AuthenticationV1beta1Api
from .apis.authorization_api import AuthorizationApi
from .apis.authorization_v1_api import AuthorizationV1Api
from .apis.authorization_v1beta1_api import AuthorizationV1beta1Api
from .apis.autoscaling_api import AutoscalingApi
from .apis.autoscaling_v1_api import AutoscalingV1Api
from .apis.autoscaling_v2alpha1_api import AutoscalingV2alpha1Api
from .apis.batch_api import BatchApi
from .apis.batch_v1_api import BatchV1Api
from .apis.batch_v2alpha1_api import BatchV2alpha1Api
from .apis.certificates_api import CertificatesApi
from .apis.certificates_v1beta1_api import CertificatesV1beta1Api
from .apis.core_api import CoreApi
from .apis.core_v1_api import CoreV1Api
from .apis.custom_objects_api import CustomObjectsApi
from .apis.extensions_api import ExtensionsApi
from .apis.extensions_v1beta1_api import ExtensionsV1beta1Api
from .apis.logs_api import LogsApi
from .apis.networking_api import NetworkingApi
from .apis.networking_v1_api import NetworkingV1Api
from .apis.policy_api import PolicyApi
from .apis.policy_v1beta1_api import PolicyV1beta1Api
from .apis.rbac_authorization_api import RbacAuthorizationApi
from .apis.rbac_authorization_v1alpha1_api import RbacAuthorizationV1alpha1Api
from .apis.rbac_authorization_v1beta1_api import RbacAuthorizationV1beta1Api
from .apis.settings_api import SettingsApi
from .apis.settings_v1alpha1_api import SettingsV1alpha1Api
from .apis.storage_api import StorageApi
from .apis.storage_v1_api import StorageV1Api
from .apis.storage_v1beta1_api import StorageV1beta1Api
from .apis.version_api import VersionApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration, ConfigurationObject, configuration



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: v1.7.3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class V1APIResource(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, categories=None, kind=None, name=None, namespaced=None, short_names=None, singular_name=None, verbs=None):
        """
        V1APIResource - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'categories': 'list[str]',
            'kind': 'str',
            'name': 'str',
            'namespaced': 'bool',
            'short_names': 'list[str]',
            'singular_name': 'str',
            'verbs': 'list[str]'
        }

        self.attribute_map = {
            'categories': 'categories',
            'kind': 'kind',
            'name': 'name',
            'namespaced': 'namespaced',
            'short_names': 'shortNames',
            'singular_name': 'singularName',
            'verbs': 'verbs'
        }

        self._categories = categories
        self._kind = kind
        self._name = name
        self._namespaced = namespaced
        self._short_names = short_names
        self._singular_name = singular_name
        self._verbs = verbs

    @property
    def categories(self):
        """
        Gets the categories of this V1APIResource.
        categories is a list of the grouped resources this resource belongs to (e.g. 'all')

        :return: The categories of this V1APIResource.
        :rtype: list[str]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """
        Sets the categories of this V1APIResource.
        categories is a list of the grouped resources this resource belongs to (e.g. 'all')

        :param categories: The categories of this V1APIResource.
        :type: list[str]
        """

        self._categories = categories

    @property
    def kind(self):
        """
        Gets the kind of this V1APIResource.
        kind is the kind for the resource (e.g. 'Foo' is the kind for a resource 'foo')

        :return: The kind of this V1APIResource.
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """
        Sets the kind of this V1APIResource.
        kind is the kind for the resource (e.g. 'Foo' is the kind for a resource 'foo')

        :param kind: The kind of this V1APIResource.
        :type: str
        """
        if kind is None:
            raise ValueError("Invalid value for `kind`, must not be `None`")

        self._kind = kind

    @property
    def name(self):
        """
        Gets the name of this V1APIResource.
        name is the plural name of the resource.

        :return: The name of this V1APIResource.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this V1APIResource.
        name is the plural name of the resource.

        :param name: The name of this V1APIResource.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def namespaced(self):
        """
        Gets the namespaced of this V1APIResource.
        namespaced indicates if a resource is namespaced or not.

        :return: The namespaced of this V1APIResource.
        :rtype: bool
        """
        return self._namespaced

    @namespaced.setter
    def namespaced(self, namespaced):
        """
        Sets the namespaced of this V1APIResource.
        namespaced indicates if a resource is namespaced or not.

        :param namespaced: The namespaced of this V1APIResource.
        :type: bool
        """
        if namespaced is None:
            raise ValueError("Invalid value for `namespaced`, must not be `None`")

        self._namespaced = namespaced

    @property
    def short_names(self):
        """
        Gets the short_names of this V1APIResource.
        shortNames is a list of suggested short names of the resource.

        :return: The short_names of this V1APIResource.
        :rtype: list[str]
        """
        return self._short_names

    @short_names.setter
    def short_names(self, short_names):
        """
        Sets the short_names of this V1APIResource.
        shortNames is a list of suggested short names of the resource.

        :param short_names: The short_names of this V1APIResource.
        :type: list[str]
        """

        self._short_names = short_names

    @property
    def singular_name(self):
        """
        Gets the singular_name of this V1APIResource.
        singularName is the singular name of the resource.  This allows clients to handle plural and singular opaquely. The singularName is more correct for reporting status on a single item and both singular and plural are allowed from the kubectl CLI interface.

        :return: The singular_name of this V1APIResource.
        :rtype: str
        """
        return self._singular_name

    @singular_name.setter
    def singular_name(self, singular_name):
        """
        Sets the singular_name of this V1APIResource.
        singularName is the singular name of the resource.  This allows clients to handle plural and singular opaquely. The singularName is more correct for reporting status on a single item and both singular and plural are allowed from the kubectl CLI interface.

        :param singular_name: The singular_name of this V1APIResource.
        :type: str
        """
        if singular_name is None:
            raise ValueError("Invalid value for `singular_name`, must not be `None`")

        self._singular_name = singular_name

    @property
    def verbs(self):
        """
        Gets the verbs of this V1APIResource.
        verbs is a list of supported kube verbs (this includes get, list, watch, create, update, patch, delete, deletecollection, and proxy)

        :return: The verbs of this V1APIResource.
        :rtype: list[str]
        """
        return self._verbs

    @verbs.setter
    def verbs(self, verbs):
        """
        Sets the verbs of this V1APIResource.
        verbs is a list of supported kube verbs (this includes get, list, watch, create, update, patch, delete, deletecollection, and proxy)

        :param verbs: The verbs of this V1APIResource.
        :type: list[str]
        """
        if verbs is None:
            raise ValueError("Invalid value for `verbs`, must not be `None`")

        self._verbs = verbs

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, V1APIResource):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: v1.7.3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class V1beta1APIServiceCondition(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, last_transition_time=None, message=None, reason=None, status=None, type=None):
        """
        V1beta1APIServiceCondition - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'last_transition_time': 'datetime',
            'message': 'str',
            'reason': 'str',
            'status': 'str',
            'type': 'str'
        }

        self.attribute_map = {
            'last_transition_time': 'lastTransitionTime',
            'message': 'message',
            'reason': 'reason',
            'status': 'status',
            'type': 'type'
        }

        self._last_transition_time = last_transition_time
        self._message = message
        self._reason = reason
        self._status = status
        self._type = type

    @property
    def last_transition_time(self):
        """
        Gets the last_transition_time of this V1beta1APIServiceCondition.
        Last time the condition transitioned from one status to another.

        :return: The last_transition_time of this V1beta1APIServiceCondition.
        :rtype: datetime
        """
        return self._last_transition_time

    @last_transition_time.setter
    def last_transition_time(self, last_transition_time):
        """
        Sets the last_transition_time of this V1beta1APIServiceCondition.
        Last time the condition transitioned from one status to another.

        :param last_transition_time: The last_transition_time of this V1beta1APIServiceCondition.
        :type: datetime
        """

        self._last_transition_time = last_transition_time

    @property
    def message(self):
        """
        Gets the message of this V1beta1APIServiceCondition.
        Human-readable message indicating details about last transition.

        :return: The message of this V1beta1APIServiceCondition.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this V1beta1APIServiceCondition.
        Human-readable message indicating details about last transition.

        :param message: The message of this V1beta1APIServiceCondition.
        :type: str
        """

        self._message = message

    @property
    def reason(self):
        """
        Gets the reason of this V1beta1APIServiceCondition.
        Unique, one-word, CamelCase reason for the condition's last transition.

        :return: The reason of this V1beta1APIServiceCondition.
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """
        Sets the reason of this V1beta1APIServiceCondition.
        Unique, one-word, CamelCase reason for the condition's last transition.

        :param reason: The reason of this V1beta1APIServiceCondition.
        :type: str
        """

        self._reason = reason

    @property
    def status(self):
        """
        Gets the status of this V1beta1APIServiceCondition.
        Status is the status of the condition. Can be True, False, Unknown.

        :return: The status of this V1beta1APIServiceCondition.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this V1beta1APIServiceCondition.
        Status is the status of the condition. Can be True, False, Unknown.

        :param status: The status of this V1beta1APIServiceCondition.
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")

        self._status = status

    @property
    def type(self):
        """
        Gets the type of this V1beta1APIServiceCondition.
        Type is the type of the condition.

        :return: The type of this V1beta1APIServiceCondition.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this V1beta1APIServiceCondition.
        Type is the type of the condition.

        :param type: The type of this V1beta1APIServiceCondition.
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, V1beta1APIServiceCondition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: v1.7.3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class V1beta1SubjectAccessReviewStatus(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, allowed=None, evaluation_error=None, reason=None):
        """
        V1beta1SubjectAccessReviewStatus - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'allowed': 'bool',
            'evaluation_error': 'str',
            'reason': 'str'
        }

        self.attribute_map = {
            'allowed': 'allowed',
            'evaluation_error': 'evaluationError',
            'reason': 'reason'
        }

        self._allowed = allowed
        self._evaluation_error = evaluation_error
        self._reason = reason

    @property
    def allowed(self):
        """
        Gets the allowed of this V1beta1SubjectAccessReviewStatus.
        Allowed is required.  True if the action would be allowed, false otherwise.

        :return: The allowed of this V1beta1SubjectAccessReviewStatus.
        :rtype: bool
        """
        return self._allowed

    @allowed.setter
    def allowed(self, allowed):
        """
        Sets the allowed of this V1beta1SubjectAccessReviewStatus.
        Allowed is required.  True if the action would be allowed, false otherwise.

        :param allowed: The allowed of this V1beta1SubjectAccessReviewStatus.
        :type: bool
        """
        if allowed is None:
            raise ValueError("Invalid value for `allowed`, must not be `None`")

        self._allowed = allowed

    @property
    def evaluation_error(self):
        """
        Gets the evaluation_error of this V1beta1SubjectAccessReviewStatus.
        EvaluationError is an indication that some error occurred during the authorization check. It is entirely possible to get an error and be able to continue determine authorization status in spite of it. For instance, RBAC can be missing a role, but enough roles are still present and bound to reason about the request.

        :return: The evaluation_error of this V1beta1SubjectAccessReviewStatus.
        :rtype: str
        """
        return self._evaluation_error

    @evaluation_error.setter
    def evaluation_error(self, evaluation_error):
        """
        Sets the evaluation_error of this V1beta1SubjectAccessReviewStatus.
        EvaluationError is an indication that some error occurred during the authorization check. It is entirely possible to get an error and be able to continue determine authorization status in spite of it. For instance, RBAC can be missing a role, but enough roles are still present and bound to reason about the request.

        :param evaluation_error: The evaluation_error of this V1beta1SubjectAccessReviewStatus.
        :type: str
        """

        self._evaluation_error = evaluation_error

    @property
    def reason(self):
        """
        Gets the reason of this V1beta1SubjectAccessReviewStatus.
        Reason is optional.  It indicates why a request was allowed or denied.

        :return: The reason of this V1beta1SubjectAccessReviewStatus.
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """
        Sets the reason of this V1beta1SubjectAccessReviewStatus.
        Reason is optional.  It indicates why a request was allowed or denied.

        :param reason: The reason of this V1beta1SubjectAccessReviewStatus.
        :type: str
        """

        self._reason = reason

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, V1beta1SubjectAccessReviewStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: v1.7.3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class V1alpha1ExternalAdmissionHook(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, client_config=None, failure_policy=None, name=None, rules=None):
        """
        V1alpha1ExternalAdmissionHook - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'client_config': 'V1alpha1AdmissionHookClientConfig',
            'failure_policy': 'str',
            'name': 'str',
            'rules': 'list[V1alpha1RuleWithOperations]'
        }

        self.attribute_map = {
            'client_config': 'clientConfig',
            'failure_policy': 'failurePolicy',
            'name': 'name',
            'rules': 'rules'
        }

        self._client_config = client_config
        self._failure_policy = failure_policy
        self._name = name
        self._rules = rules

    @property
    def client_config(self):
        """
        Gets the client_config of this V1alpha1ExternalAdmissionHook.
        ClientConfig defines how to communicate with the hook. Required

        :return: The client_config of this V1alpha1ExternalAdmissionHook.
        :rtype: V1alpha1AdmissionHookClientConfig
        """
        return self._client_config

    @client_config.setter
    def client_config(self, client_config):
        """
        Sets the client_config of this V1alpha1ExternalAdmissionHook.
        ClientConfig defines how to communicate with the hook. Required

        :param client_config: The client_config of this V1alpha1ExternalAdmissionHook.
        :type: V1alpha1AdmissionHookClientConfig
        """
        if client_config is None:
            raise ValueError("Invalid value for `client_config`, must not be `None`")

        self._client_config = client_config

    @property
    def failure_policy(self):
        """
        Gets the failure_policy of this V1alpha1ExternalAdmissionHook.
        FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail. Defaults to Ignore.

        :return: The failure_policy of this V1alpha1ExternalAdmissionHook.
        :rtype: str
        """
        return self._failure_policy

    @failure_policy.setter
    def failure_policy(self, failure_policy):
        """
        Sets the failure_policy of this V1alpha1ExternalAdmissionHook.
        FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail. Defaults to Ignore.

        :param failure_policy: The failure_policy of this V1alpha1ExternalAdmissionHook.
        :type: str
        """

        self._failure_policy = failure_policy

    @property
    def name(self):
        """
        Gets the name of this V1alpha1ExternalAdmissionHook.
        The name of the external admission webhook. Name should be fully qualified, e.g., imagepolicy.kubernetes.io, where \"imagepolicy\" is the name of the webhook, and kubernetes.io is the name of the organization. Required.

        :return: The name of this V1alpha1ExternalAdmissionHook.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this V1alpha1ExternalAdmissionHook.
        The name of the external admission webhook. Name should be fully qualified, e.g., imagepolicy.kubernetes.io, where \"imagepolicy\" is the name of the webhook, and kubernetes.io is the name of the organization. Required.

        :param name: The name of this V1alpha1ExternalAdmissionHook.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def rules(self):
        """
        Gets the rules of this V1alpha1ExternalAdmissionHook.
        Rules describes what operations on what resources/subresources the webhook cares about. The webhook cares about an operation if it matches _any_ Rule.

        :return: The rules of this V1alpha1ExternalAdmissionHook.
        :rtype: list[V1alpha1RuleWithOperations]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """
        Sets the rules of this V1alpha1ExternalAdmissionHook.
        Rules describes what operations on what resources/subresources the webhook cares about. The webhook cares about an operation if it matches _any_ Rule.

        :param rules: The rules of this V1alpha1ExternalAdmissionHook.
        :type: list[V1alpha1RuleWithOperations]
        """

        self._rules = rules

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, V1alpha1ExternalAdmissionHook):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
